@@ -65,41 +65,23 @@ use G::Seq::Align;
 use G::Seq::COMGA;
 use G::Seq::GenomeMap;
 use G::Seq::ImaGene;
+use G::Seq::PathwayAlignment;
 use G::Tools::Graph;
-use G::Tools::Mapping;
-use G::Tools::Blast;
-use G::Tools::Fasta;
 use G::Tools::EMBOSS;
 use G::Tools::Alignment;
-use G::Tools::HMMER;
-use G::Tools::Repeat;
-use G::Tools::SIM4;
-use G::Tools::Cap3;
 use G::Tools::COGs;
 use G::Tools::GPAC;
 use G::Tools::GOA;
 use G::Tools::GlimmerM;
-use G::Tools::Literature;
 use G::Tools::KEGG_API;
 use G::Tools::PEC;
 use G::Tools::Statistics;
 use G::Tools::GMap;
 use G::Tools::WebServices;
-use G::SystemsBiology::PathwayAlignment;
-use G::SystemsBiology::KEGG;
-use G::SystemsBiology::BioLayout;
-use G::SystemsBiology::Interaction;
-use G::SystemsBiology::DotE;
+use G::Tools::DotE;
 
-# import "presage" classes
-use G::System::BAS;
-use G::System::GEMS;
-use G::System::COMGA;
-use G::System::CHI;
-use G::System::ReL8;
-use G::System::FuncD;
 
-our @EXPORT = qw(load opt_list);
+our @EXPORT = qw(load opt_list method_list);
 
 # export odyssay functions
 push(@EXPORT, @G::Seq::AminoAcid::EXPORT);
@@ -118,38 +100,21 @@ push(@EXPORT, @G::Seq::Align::EXPORT);
 push(@EXPORT, @G::Seq::COMGA::EXPORT);
 push(@EXPORT, @G::Seq::ImaGene::EXPORT);
 push(@EXPORT, @G::Seq::GenomeMap::EXPORT);
+push(@EXPORT, @G::Seq::PathwayAlignment::EXPORT);
 push(@EXPORT, @G::Tools::Graph::EXPORT);
-push(@EXPORT, @G::Tools::Mapping::EXPORT);
-push(@EXPORT, @G::Tools::Blast::EXPORT);
-push(@EXPORT, @G::Tools::Fasta::EXPORT);
 push(@EXPORT, @G::Tools::EMBOSS::EXPORT);
 push(@EXPORT, @G::Tools::Alignment::EXPORT);
-push(@EXPORT, @G::Tools::HMMER::EXPORT);
-push(@EXPORT, @G::Tools::Repeat::EXPORT);
-push(@EXPORT, @G::Tools::SIM4::EXPORT);
-push(@EXPORT, @G::Tools::Cap3::EXPORT);
 push(@EXPORT, @G::Tools::COGs::EXPORT);
 push(@EXPORT, @G::Tools::GPAC::EXPORT);
 push(@EXPORT, @G::Tools::GOA::EXPORT);
 push(@EXPORT, @G::Tools::GlimmerM::EXPORT);
-push(@EXPORT, @G::Tools::Literature::EXPORT);
 push(@EXPORT, @G::Tools::KEGG_API::EXPORT);
 push(@EXPORT, @G::Tools::PEC::EXPORT);
 push(@EXPORT, @G::Tools::Statistics::EXPORT);
 push(@EXPORT, @G::Tools::GMap::EXPORT);
 push(@EXPORT, @G::Tools::WebServices::EXPORT);
-push(@EXPORT, @G::SystemsBiology::PathwayAlignment::EXPORT);
-push(@EXPORT, @G::SystemsBiology::KEGG::EXPORT);
-push(@EXPORT, @G::SystemsBiology::BioLayout::EXPORT);
-push(@EXPORT, @G::SystemsBiology::Interaction::EXPORT);
-push(@EXPORT, @G::SystemsBiology::DotE::EXPORT);
-push(@EXPORT, @G::System::BAS::EXPORT);
-push(@EXPORT, @G::System::GEMS::EXPORT);
-push(@EXPORT, @G::System::COMGA::EXPORT);
-push(@EXPORT, @G::System::STeP::EXPORT);
-push(@EXPORT, @G::System::CHI::EXPORT);
-push(@EXPORT, @G::System::ReL8::EXPORT);
-push(@EXPORT, @G::System::FuncD::EXPORT);
+push(@EXPORT, @G::Tools::DotE::EXPORT);
+
 push(@EXPORT, @G::DB::SDB::EXPORT);
 push(@EXPORT, @G::DB::BDB::EXPORT);
 push(@EXPORT, @SubOpt::EXPORT);
@@ -169,13 +134,41 @@ sub load{
 sub opt_list{
     my $sub = shift;
 
-    set_opt_list(1);
+    SubOpt::set_opt_list(1);
     eval("&{$sub}");
-    set_opt_list(0);
+    SubOpt::set_opt_list(0);
 
     return opt_val();
 }
 
+sub method_list{
+    my $opt = shift;
+    my %system;
+
+    for my $name (qw/
+		  p puts say readFile writeFile 
+		  opt_as_gb opt_default opt_get opt_list opt_val method_list
+		  msg_ask_interface msg_error msg_send msg_gimv msg_interface msg_percent msg_progress msg_set_gimv msg_system_console msg_term_console
+		  sdb_exists sdb_load sdb_save _sdb_path _set_sdb_path
+		  db_dbi db_exists db_load db_path db_save db_set_path
+		  pass_send pass_get
+		  /){
+	$system{$name} ++;
+    }
+
+    if($opt){
+	return (sort keys %system);
+    }else{
+	my @return;
+
+	for my $name (@EXPORT){
+	    push(@return, $name) unless($system{$name} || $name eq 'cum_gcskew' || $name eq '_UniMultiGrapher');
+	}
+
+	return sort @return;
+    }
+}
+
 #::::::::::::::::::::::::::::::
 #          Perldoc
 #::::::::::::::::::::::::::::::
@@ -381,6 +374,20 @@ G - G-language Genome Analysis Environment core interface module
 
 =cut
 
+=head2 method_list
+
+   Name: method_list   -   get the list of availabel G-language GAE functions
+
+   Description:
+         Returns an array of available method names. 
+         When 1 is supplied as an argument, returns an array of API-related
+         method names.
+
+         eg. @methods = method_list();     # contains more than 100 analysis functions
+             @APImethods = method_list(1); # contains around 50 API-related methods.
+
+=cut
+
 =head2 translate
 
    Name: translate   -   translate a nucleotide sequence to amino acid sequence
@@ -564,7 +571,9 @@ G - G-language Genome Analysis Environment core interface module
    Name: $gb->intergenic()   -   get a list of IDs of intergenic regions
 
    Description:
-         Returns the array of all IDs of intergenic regions.
+         Returns the array of all IDs of intergenic regions. 
+         Here "intergenic region" is defined as the region in a genome
+         between coding and stable RNA genes. 
 
 =cut
 
