@@ -626,47 +626,42 @@ sub set_intergenic{
     my $gb = shift;
     my $num = 1;
     my $i = 0;
-    my $cds = scalar($gb->cds());
-    my $so = $gb->{"CDS$cds"}->{end} + 1;
-    
-    while(defined(%{$gb->{"CDS$i"}})){
-	if($i == 0){
-	    my $sta = $gb->{CDS1}->{start} - 1;
+    my $interface = msg_ask_interface();
+    msg_interface("NULL");
+    my @cds = $gb->find(-type=>"CDS|RNA");
+
+    foreach my $feature (@cds){
+	if($i == 0 && $gb->{$feature}->{start} < $gb->{$feature}->{end}){
 	    $gb->{"INTER$num"}->{start} = 1;
-	    $gb->{"INTER$num"}->{end} = $sta;
+	    $gb->{"INTER$num"}->{end} = $gb->{$feature}->{start} - 1;
 	    $gb->{"INTER$num"}->{direction} = "direct";
 	    $gb->{"INTER$num"}->{left} = undef;
-	    $gb->{"INTER$num"}->{right} = sprintf("FEATURE%d", $gb->{CDS1}->{feature});
+	    $gb->{"INTER$num"}->{right} = $feature;
 	    $gb->{"INTER$num"}->{on} = 1;
 	    $num++;
-	}elsif($i == $cds){
-	    $gb->{"INTER$num"}->{start} = $so;
+	}elsif($i == $#cds && $gb->{$cds[-1]}->{end} + 1 < $gb->{SEQ}){
+	    $gb->{"INTER$num"}->{start} = $gb->{$cds[-1]}->{end} + 1;
 	    $gb->{"INTER$num"}->{end} = length $gb->{SEQ};
 	    $gb->{"INTER$num"}->{direction} = "direct";
-	    $gb->{"INTER$num"}->{left} = sprintf("FEATURE%d", $gb->{"CDS$cds"}->{feature});
+	    $gb->{"INTER$num"}->{left} = $feature;
 	    $gb->{"INTER$num"}->{right} = undef;
 	    $gb->{"INTER$num"}->{on} = 1;
 	    $num++;
 	}elsif($i > 0){
-	    my $it = $i + 1; 
-	    my $start = $gb->{"CDS$i"}->{end};
-	    my $end = $gb->{"CDS$it"}->{start};
-
-	    if($start < $end){
-		$start ++;
-		$end --;
-		$gb->{"INTER$num"}->{start} = $start;
-		$gb->{"INTER$num"}->{end} = $end;
+	    if($gb->{$cds[$i - 1]}->{end} < $gb->{$feature}->{start}){
+		$gb->{"INTER$num"}->{start} = $gb->{$cds[$i - 1]}->{end} + 1;
+		$gb->{"INTER$num"}->{end} = $gb->{$feature}->{start} - 1;
 		$gb->{"INTER$num"}->{direction} = "direct";
-		$gb->{"INTER$num"}->{left} = sprintf("FEATURE%d", $gb->{"CDS$i"}->{feature});
-		$gb->{"INTER$num"}->{right} = sprintf("FEATURE%d", $gb->{"CDS$it"}->{feature});
+		$gb->{"INTER$num"}->{left} = $cds[$i - 1];
+		$gb->{"INTER$num"}->{right} = $feature;
 		$gb->{"INTER$num"}->{on} = 1;
 		$num++;
 	    }
 	}
 	$i++;
     }
-    
+
+    msg_interface($interface);
     $intergenic = 1;
 }
 
