@@ -95,8 +95,6 @@ my %dayhoff = (
 	       V=>6.6, W=>1.3, X=>0.0, Y=>3.4, Z=>0.0);
 
 
-__DATA__
-
 
 
 #:::::::::::::::::::::::::::::::::
@@ -137,11 +135,6 @@ sub three2one{
     return %three2one;
 }
 
-
-sub 
-
-
-
 =head2 peptide_mass
 
        Author: Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
@@ -157,7 +150,7 @@ sub peptide_mass{
     my $gb = opt_as_gb(shift @argv);
     my $totmass = 0;
 
-    foreach my $amino (split(//, $gb->{SEQ})){
+    foreach my $amino (split(//, uc($gb->{SEQ}))){
 	$totmass += $mass{$amino};
     }
 
@@ -181,13 +174,13 @@ sub calc_pI{
     my $tmpcharge = 0;
     my $step = 3.5;
     my %num;
-    $num{C} = $gb->{SEQ} =~ tr/C/C/;
-    $num{D} = $gb->{SEQ} =~ tr/D/D/;
-    $num{E} = $gb->{SEQ} =~ tr/E/E/;
-    $num{H} = $gb->{SEQ} =~ tr/H/H/;
-    $num{K} = $gb->{SEQ} =~ tr/K/K/;
-    $num{R} = $gb->{SEQ} =~ tr/R/R/;
-    $num{Y} = $gb->{SEQ} =~ tr/Y/Y/;
+    $num{C} = uc($gb->{SEQ}) =~ tr/C/C/;
+    $num{D} = uc($gb->{SEQ}) =~ tr/D/D/;
+    $num{E} = uc($gb->{SEQ}) =~ tr/E/E/;
+    $num{H} = uc($gb->{SEQ}) =~ tr/H/H/;
+    $num{K} = uc($gb->{SEQ}) =~ tr/K/K/;
+    $num{R} = uc($gb->{SEQ}) =~ tr/R/R/;
+    $num{Y} = uc($gb->{SEQ}) =~ tr/Y/Y/;
 
     while(1){
 	my $charge = 
@@ -216,16 +209,6 @@ sub calc_pI{
     return $pI;
 }
 
-=head2 _charge
-
-       Author: Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
-        Usage: $charge = charge(pK, pH) for positive
-               $charge = charge(pH, pK) for negative
-      Options: None.
-  Description: intended for internal use only
-      History: created 2001.04.04
-
-=cut
 
 sub _charge {
     my $first = shift;
