@@ -325,11 +325,7 @@ sub rep_ori_ter {
 
 
 
-
-
-
-
-=head2 leading_strand 
+=head2 leading_strand
 
  Name: leading_strand   -   get the sequences of leading strands
 
@@ -688,6 +684,8 @@ sub cum_gcskew {
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
  History:
+   20090313-01 updated according to the update of $gb->intergenic() to 
+               include stable RNA genes as genetic elements
    20080421-01 now returns references of result arrays
    20040610-01 updated to handle introns and exons
    20040601-01 bug fix for output=>"f" option
@@ -714,40 +712,26 @@ sub genomicskew {
     my (@gcskew, @betskew, @geneskew, @thirdskew);
     my @location = (0..$divide);
     my ($j, $window, $CDS, $BET, $THIRD);
-    my $before = 0;
-    my $i = 1;
-    
+
     foreach my $cds ($gb->cds()){
-	my $seq;
-
-	if (length $gb->{$cds}->{join}){
-	    foreach my $line (split(/,/, $gb->{$cds}->{join})){
-		$line =~ tr/c//d;
-		my ($start, $end) = split(/\.\./, $line, 2);
-		$seq .= $gb->get_gbkseq($start, $end);
-	    }
-	}else{
-	    $seq = $gb->get_gbkseq($gb->{$cds}->{start}, $gb->{$cds}->{end});
-	}
-
+	next if (length $gb->{$cds}->{join});
+	my $seq .= $gb->get_gbkseq($gb->{$cds}->{start}, $gb->{$cds}->{end});
 	$CDS .= $seq;
-	
-	for($j = 2; $j <= length($seq); $j += 3){
-	    if ($gb->{"$cds"}->{direction} eq 'complement'){
-		$THIRD .= substr($seq, $j, 1);
-	    }else{
-		$THIRD .= substr($seq, $j - 2, 1);
-	    }
-	}
-
-	$BET .= substr($gb->{SEQ}, $before, $gb->{"$cds"}->{start} - $before)
-	    unless ($gb->{"$cds"}->{start} - $before < 1);
-
-	$BET .= join('', $gb->get_intron($cds)) if($intron);
-
-	$before = $gb->{"$cds"}->{end};
+       
+        for($j = 2; $j <= length($seq); $j += 3){
+            if ($gb->{"$cds"}->{direction} eq 'complement'){
+                $THIRD .= substr($seq, $j, 1);
+            }else{
+                $THIRD .= substr($seq, $j - 2, 1);
+            }
+        }
     }
-    $i = 0;
+
+    foreach my $cds ($gb->intergenic()){
+	$BET .= $gb->get_geneseq($cds);
+    }
+
+    my $i = 0;
     
     $window = int(length($gb->{SEQ}) / $divide);
     while($i <= $divide){
