@@ -45,28 +45,12 @@ __DATA__
 
 =head1 NAME
 
-G::Seq::Operon - Perl extension for blah blah blah
-
-=head1 SYNOPSIS
-
-  use G::Seq::Operon;
-  blah blah blah
+G::Seq::Operon - Retrieves operon information for bacterial genoms
 
 =head1 DESCRIPTION
 
-Stub documentation for G::Seq::Operon was created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
-
-=head1 AUTHOR
-
-A. U. Thor, a.u.thor@a.galaxy.far.far.away
-
-=head1 SEE ALSO
-
-perl(1).
+    This class is a part of G-language Genome Analysis Environment, 
+    collecting sequence analysis methods related to operons.
 
 =cut
 
@@ -78,17 +62,21 @@ perl(1).
 
 =head2 set_operon
 
-  Name: set_operon   -   set operon information from RegulonDB
+  Name: set_operon   -   set operon information from RegulonDB/ODB
 
   Description:
-    This program retrieves the operon information from RegulonDB, and adds this
-    to the given genome data. !!!This method currently only works for E.coli!!!
+    This program retrieves the operon information from 
+      1. RegulonDB for Escherichia coli K12
+      2. Operon Database for other bacteria
+    and annotation to the given genome data. 
 
     Two attributes are added to each CDS hash.
         $genome->{$cds}->{operon}
     contains the name of the operon to which the gene belongs, and 
         $genome->{$cds}->{operonN}
     contains the rank order of the gene within the operon.
+        $genome->{$cds}->{operonEvidence}
+    contains evidence of the operon information (available for E.coli only)
 
   Usage:
     set_operon($gb);
@@ -97,14 +85,19 @@ perl(1).
    None.
 
   References:
-   1. Salgado H et al. (2006) "RegulonDB (version 5.0): Escherichia coli K-12 transcriptional
-      regulatory network, operon organization, and growth conditions", Nucleic Acids Res. 
-      1;34(Database issue):D394-7
+   1. Gama-Castro S et al. (2008) "RegulonDB (version 6.0): gene regulation model 
+      of Escherichia coli K-12 beyond transcription, active (experimental) annotated 
+      promoters and Textpresso navigation.", Nucleic Acids Res. 1;36(Database issue):D120-4
+
+   2. Okuda S et al. "ODB: a database of operons accumulating known operons across multiple genomes."
+      Nucleic Acids Res  2006 Jan 1;34(Database issue):D358-62
 
   Author: 
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
+   20090313-01 added support for other organisms using Operon Database
+   20090313-02 modified to match latest version of RegulonDB format (6.0)
    20070829-01 patched to match latest version of RegulonDB formamt
                (patch by Hiroyuki Nakamura <t04632hn@sfc.keio.ac.jp>
    20061003-01 updated to use data from RegulonDB
@@ -115,7 +108,7 @@ perl(1).
 
 sub set_operon {
     my @args = opt_get(@_);
-    my $gb = shift @args;
+    my $gb = opt_as_gb(shift @args);
 
     if ($gb->{LOCUS}->{id} eq 'U00096' || $gb->{LOCUS}->{id} eq 'NC_000913'){
 
@@ -128,21 +121,21 @@ sub set_operon {
 	open(FILE, $dir) || die($!);
 	while (<FILE>) {
 	    chomp;
+	    my $line = $_;
 
 	    if (/^Columns\:/) {
 	      $flag++;
 	      next;
 	    }
-	    elsif(/^\t\(\d\)\s/) {
+	    elsif(/^\s+\(\d\)\s/) {
 	      $flag++;
 	      next;
 	    }
 
-	    if($flag == 5){
-
+	    if($flag == 6){
 		my %geneOrder;
 
-		my ($operon, $num, $direction, $genes) = split(/\t/, $_, 4);
+		my ($operon, $num, $direction, $genes, $evidence) = split(/\t/, $_, 5);
 		next unless($num >= 2);
 
 		foreach my $genepair (split(/,/, $genes)){
@@ -153,6 +146,7 @@ sub set_operon {
 
 		    if($cds){
 			$gb->{$cds}->{operon} = $operon;
+			$gb->{$cds}->{operonEvidence} = $evidence;
 			$geneOrder{$cds} = $gb->{$cds}->{start};
 		    }
 		}
@@ -169,9 +163,9 @@ sub set_operon {
 			$i ++;
 		    }
 		}
-
 	    }else{
-		msg_error($_, "\n");
+		$line =~ s/[^a-zA-Z0-9\-,\.\(\):\"\' ]//g;
+		msg_error($line, "\n");
 	    }
 	}
 	close(FILE);
@@ -181,16 +175,42 @@ sub set_operon {
 	}
 
    }else{
-       msg_error("No Operon data for this species.\n\n");
+
+       my $url = 'http://www.g-language.org/db/operon/' . $gb->{LOCUS}->{id} . '.csv';
+       my $dir = $ENV{HOME} . '/.glang/data/Operon' . $gb->{LOCUS}->{id} . '.txt';
+       mirror($url, $dir);
+       die("No Operon data for this species.\n\n") unless(-e $dir);
+       
+       my $flag = 0;
+       open(FILE, $dir) || die($!);
+       while (<FILE>) {
+	   chomp;
+	   my ($operonName, $operonNum, @operons) = split(/\,/, $_);
+	   my @list = @operons;
+
+	   @list = reverse(@operons) if($gb->{$operons[0]}->{direction} eq 'complement');
+
+	   my $i = 1;
+	   foreach my $cds (@list){
+	       $cds =~ s/BG/BSU/g if($gb->{LOCUS}->{id} eq 'NC_000964');
+	       $gb->{$cds}->{operon} = $operonName;
+	       $gb->{$cds}->{operonN} = $i;
+	       $i ++;
+	   }
+       }
+       close(FILE);
+
+       foreach my $cds ($gb->cds()){
+	   $gb->{$cds}->{operonN} = 0 unless(length $gb->{$cds}->{operon});
+       }
    }
 
-    return 1;
+    return $gb;
 }
 
 
 
 
 
-
 1;
 
