@@ -209,6 +209,7 @@ sub signature {
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
+    20090312-01 fixed bug in default option
     20010829-01 initial posting
 
 =cut
@@ -217,7 +218,7 @@ sub signature {
 
 
 sub palindrome {
-    &opt_default(gtmatch=>0, loop=>0, shortest=>4, -output=>"stdout", -filename=>"palindrome.csv");
+    &opt_default(gtmatch=>0, loop=>0, shortest=>4, output=>"stdout", filename=>"palindrome.csv");
     my @args = opt_get(@_);
     my $gb = opt_as_gb(shift @args);
     my $length = int(opt_val("shortest") / 2);
@@ -472,7 +473,7 @@ sub find_iteron {
     This method serves as the basic function for other find_* methods.
 
   Usage: 
-    @positions = find_patter($genome, "pattern")
+    @positions = find_pattern($genome, "pattern")
     
   Options:
     -output    stdout to print data (default: stdout)
@@ -766,6 +767,7 @@ sub baseParingTest {
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
     
   History:
+    20090312-01 minor bug fix
     20070206-01 initial posting
 
 =cut
@@ -792,7 +794,7 @@ sub nucleotide_periodicity {
 	}
     }
 
-    _Unimultigrapher([0..($window - 1)], \@data, -filename=>$filename);
+    _UniMultiGrapher([0..($window - 1)], \@data, -filename=>$filename);
     msg_gimv("graph/$filename") if ($output eq 'show');
 
     return @data;
