@@ -33,8 +33,11 @@ use strict;
 use base qw(Exporter);
 use SelfLoader;
 
+use LWP::Simple;
+
 our @EXPORT = qw(
 		 ws
+		 togoWS
 		 );
 
 
@@ -48,7 +51,7 @@ __DATA__
 
 =head1 NAME
 
-    G::Tools::WebServices - Interface to web services, including BioMOBY
+    G::Tools::WebServices - Interface to web services, including BioMOBY and TogoWS
 
 =head1 DESCRIPTION
 
@@ -64,6 +67,93 @@ __DATA__
 #:::::::::::::::::::::::::::::::::
 
 
+=head2 togoWS
+
+ Name: togoWS   -   runs togoWS REST web services
+
+ Description:
+    This is a wrapper around togoWS REST web services provided at
+    http://togows.dbcls.jp/.
+    
+ Usage:
+    #search
+    @ids = togoWS(-search=>"keyword", -db=>"database");
+
+    #entry
+    $entry = togoWS(@ids);
+
+ Options:
+    -search  required option for keyword searching. 
+    -db      name of the database for searching and entry retrieval
+             required for searching, but not required for entry 
+             retrieval, since corresponding database is automatically
+             selected from the ID format. However, majority of the 
+             databases simply use large numbers as IDs, which all
+             result in "pubmed" as the databases. Therefore, use 
+             of this option is necessary for IDs that are only numbers.
+    -field   field name for entry retrieval (optional)
+    -format  format name for entry retrieval (optional)
+
+ Author: 
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
+
+ History:
+   20090313-01 initial posting
+
+=cut
+
+
+sub togoWS{
+    opt_default(db=>'', format=>'', field=>'', search=>'');
+    my @args = opt_get(@_);
+    my %opt = opt_val();
+
+    if(length $opt{search}){
+	$opt{db} = 'uniprot' unless(length $opt{db});
+	return split(/\n/, get('http://togows.dbcls.jp/search/' . $opt{db} . '/' . $opt{search}));
+    }else{
+	unless(length $opt{db}){
+	    if($args[0] =~ /^K\d+$/){
+		$opt{db} = 'orthology';
+	    }elsif($args[0] =~ /^\d\.\d+\.\d+\.\d+$/){
+		$opt{db} = 'enzyme';
+	    }elsif($args[0] =~ /^C\d+$/){
+		$opt{db} = 'compound';
+	    }elsif($args[0] =~ /^D\d+$/){
+		$opt{db} = 'drug';
+	    }elsif($args[0] =~ /^G\d+$/){
+		$opt{db} = 'glycan';
+	    }elsif($args[0] =~ /^R\d+$/){
+		$opt{db} = 'reaction';
+	    }elsif($args[0] =~ /^BIOMD\d+$/){
+		$opt{db} = 'biomodels';
+	    }elsif($args[0] =~ /^MODEL\d+$/){
+		$opt{db} = 'biomodels';
+	    }elsif($args[0] =~ /^GO:\d+$/){
+		$opt{db} = 'go';
+	    }elsif($args[0] =~ /^IPR\d+$/){
+		$opt{db} = 'interpro';
+	    }elsif($args[0] =~ /^REACT_\d+$/){
+		$opt{db} = 'reactome';
+	    }elsif($args[0] =~ /^[a-zA-Z0-9]+_[a-zA-Z0-9]+$/){
+		$opt{db} = 'uniprot';
+	    }else{
+		$opt{db} = 'pubmed';
+	    }
+	}
+
+	my $url = 'http://togows.dbcls.jp/entry/' . $opt{db} . '/' . join(',', @args);
+	$url .= '/' . $opt{field} if (length $opt{field});
+	$url .= '.' . $opt{format} if (length $opt{format});
+
+	return get($url);
+    }
+    
+}
+
+
+
+
 =head2 ws
 
  Name: ws   -   runs web services through BioMOBY
